@@ -1,9 +1,6 @@
-from . import _patch
 from .annotation import sink
 from .annotation import source
 from .run import run_worker
 from .worker import BaseWorker
 
-__version__ = '0.21'
-
-del _patch
+__version__ = '0.22'
